@@ -193,7 +193,7 @@ cv.waldmmpc <- function(target, dataset, wei = NULL, kfolds = 10, folds = NULL,
     mat <- matrix(nrow = length(best_model[[ 1 ]]), ncol = kfolds)
     for ( i in 1:nrow(mat) )  mat[i, ] <- as.vector( best_model[[ 1 ]][[ i ]]$performances )  
     
-    opti <- Rfast::rowmeans(mat)
+    opti <- rowMeans(mat, na.rm = TRUE)
     bestpar <- which.max(opti)
     best_model$best_configuration = conf_mmpc[[bestpar]]$configuration
     best_model$best_performance <- max( opti )
