@@ -11,8 +11,8 @@ fbed.geelm.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, wei = NUL
   sa <- NULL
   pva <- NULL
   
-  ep <- Rfast::check_data(x)
-  if ( sum(ep>0) > 0 )  x[, ep] <- rnorm( n * ep )
+  zevar <- Rfast::check_data(x)
+  if ( sum( zevar > 0 ) > 0 )  x[, zevar] <- rnorm( n * length(zevar) )
   
   runtime <- proc.time()
   
@@ -28,6 +28,8 @@ fbed.geelm.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, wei = NUL
     univ <- list()
     univ$stat <- stat
     univ$pvalue <- pval
+    univ$stat[zevar] <- 0
+    univ$pvalue[zevar] <- 0
   } else {
     n.tests <- 0
     stat <- univ$stat
@@ -70,7 +72,7 @@ fbed.geelm.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, wei = NUL
     
     if (K == 1) {
       d0 <- length(sela)
-      for ( i in ind[-sela] )  {
+      for ( i in ind[-c(sela, zevar)] )  {
         fit2 <- try( geepack::geeglm( y ~ reps+ x[, sela] + x[, i], family = gaussian, id = id, waves = reps, weights = wei, corstr = correl, std.err = se ), silent = TRUE)
         if ( identical( class(fit2), "try-error" ) ) {
           stat[i] <- 0
@@ -80,7 +82,7 @@ fbed.geelm.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, wei = NUL
           stat[i] <- mod[nr, 3]
         } 
       }
-      n.tests[2] <- length( ind[-sela] )
+      n.tests[2] <- length( ind[-c(sela, zevar)] )
       pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = TRUE)
       s <- which(pval < sig)
       sel <- which.min(pval) * ( length(s)>0 )
@@ -116,7 +118,7 @@ fbed.geelm.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, wei = NUL
     
     if ( K > 1) {
       
-      for ( i in ind[-sela] )  {
+      for ( i in ind[-c(sela, zevar)] )  {
         fit2 <- try( geepack::geeglm( y ~ reps+ x[, sela] + x[, i], family = gaussian, id = id, waves = reps, weights = wei, corstr = correl, std.err = se ), silent = TRUE)
         if ( identical( class(fit2), "try-error" ) ) {
           stat[i] <- 0
@@ -126,7 +128,7 @@ fbed.geelm.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, wei = NUL
           stat[i] <- mod[nr, 3]
         } 
       }
-      n.tests[2] <- length( ind[-sela] )
+      n.tests[2] <- length( ind[-c(sela,zevar)] )
       pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = TRUE)
       s <- which(pval < sig)
       sel <- which.min(pval) * ( length(s)>0 )
@@ -162,7 +164,7 @@ fbed.geelm.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, wei = NUL
       vim <- 1
       while ( vim < K  & card[vim + 1] - card[vim] > 0 ) {
         vim <- vim + 1
-        for ( i in ind[-sela] )  {
+        for ( i in ind[-c(sela, zevar)] )  {
           fit2 <- try( geepack::geeglm( y ~ reps+ x[, sela] + x[, i], family = gaussian, id = id, waves = reps, weights = wei, corstr = correl, std.err = se ), silent = TRUE)
           if ( identical( class(fit2), "try-error" ) ) {
             stat[i] <- 0
@@ -172,7 +174,7 @@ fbed.geelm.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, wei = NUL
             stat[i] <- mod[nr, 3]
           } 
         }
-        n.tests[vim + 1] <- length( ind[-sela] )
+        n.tests[vim + 1] <- length( ind[-c(sela, zevar)] )
         pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = TRUE)
         s <- which(pval < sig)
         sel <- which.min(pval) * ( length(s)>0 )
