@@ -12,8 +12,8 @@ fbed.glmm.ordinal.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, we
   sa <- NULL
   pva <- NULL
   
-  ep <- Rfast::check_data(x)
-  if ( sum(ep>0) > 0 )  x[, ep] <- rnorm( n * ep )
+  zevar <- Rfast::check_data(x)
+  if ( sum( zevar > 0 ) > 0 )  x[, zevar] <- rnorm( n * length(zevar) )
   
   runtime <- proc.time()
   
@@ -28,6 +28,8 @@ fbed.glmm.ordinal.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, we
     univ <- list()
     univ$stat <- stat
     univ$pvalue <- pval
+	univ$stat[zevar] <- 0
+	univ$pvalue[zevar] <- 0
   } else {
     n.tests <- 0
     stat <- univ$stat
@@ -68,11 +70,11 @@ fbed.glmm.ordinal.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, we
     card <- sum(sela > 0)
     
     if (K == 1) {
-      for ( i in ind[-sela] )  {
+      for ( i in ind[-c(sela, zevar)] )  {
         fit2 <- ordinal::clmm( y ~ x[, c(sela, i)] + reps + (1|id), weights = wei )
         lik2[i] <- logLik( fit2 )
       }
-      n.tests[2] <- length( ind[-sela] )
+      n.tests[2] <- length( ind[-c(sela, zevar)] )
       stat <- 2 * (lik2 - lik1)
       pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = TRUE)
       s <- which(pval < sig)
@@ -109,11 +111,11 @@ fbed.glmm.ordinal.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, we
     
     if ( K > 1) {
       
-      for ( i in ind[-sela] )  {
+      for ( i in ind[-c(sela, zevar)] )  {
         fit2 <- ordinal::clmm( y ~ x[, c(sela, i)] + reps + (1|id), weights = wei )
         lik2[i] <- logLik( fit2 )
       }
-      n.tests[2] <- length( ind[-sela] ) 
+      n.tests[2] <- length( ind[-c(sela, zevar)] ) 
       stat <- 2 * (lik2 - lik1)
       pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = TRUE)
       s <- which(pval < sig)
@@ -150,11 +152,11 @@ fbed.glmm.ordinal.reps <- function(y, x, id, reps, univ = NULL, alpha = 0.05, we
       vim <- 1
       while ( vim < K  & card[vim + 1] - card[vim] > 0 ) {
         vim <- vim + 1
-        for ( i in ind[-sela] )  {
+        for ( i in ind[-c(sela, zevar)] )  {
           fit2 <- ordinal::clmm( y ~ x[, c(sela, i)] + reps + (1|id), weights = wei )
           lik2[i] <- logLik( fit2 )
         }
-        n.tests[vim + 1] <- length( ind[-sela] )
+        n.tests[vim + 1] <- length( ind[-c(sela, zevar)] )
         stat <- 2 * (lik2 - lik1)
         pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = TRUE)
         s <- which(pval < sig)
