@@ -1,4 +1,4 @@
-mmpc.path <- function(target, dataset, wei = NULL, max_ks = NULL, alphas = NULL , test = NULL , user_test = NULL, ncores = 1) {
+mmpc.path <- function(target, dataset, wei = NULL, max_ks = NULL, alphas = NULL, test = NULL, user_test = NULL, ncores = 1) {
   
   if( is.null(alphas) )  alphas <- c(0.1, 0.05, 0.01)
   if( is.null(max_ks) )   max_ks <- c(4, 3, 2)  
@@ -22,22 +22,23 @@ mmpc.path <- function(target, dataset, wei = NULL, max_ks = NULL, alphas = NULL
   for (i in 1:nalpha) {
     for (j in 1:nmaxk) {
       
-      results <- MMPC(target, dataset, max_k = max_ks[j], threshold = alphas[i], test = test, ini = iniset, wei = wei, hash = TRUE, hashObject = inihash, ncores = ncores)
+      results <- MMPC(target, dataset, max_k = max_ks[j], threshold = alphas[i], test = test, ini = iniset, 
+                      wei = wei, hash = TRUE, hashObject = inihash, ncores = ncores)
       iniset <- results@univ
-      inihash <- results@hashObject;
+      inihash <- results@hashObject
       
       a <- mmpc.model(target, dataset, wei = wei, results)$signature 
       
       if ( !is.null(a) ) {
       bic[i, j] <- a[length(a)]    
-      } else bic[i, j] <- NULL
+      } else bic[i, j] <- NA
       
-      size[i, j] <- length( results@selectedVars );    
+      size[i, j] <- length( results@selectedVars )    
       k <- (i - 1) * maxj + j
       vars[[ k ]] <-  results@selectedVars
       names(vars)[[ k ]] <- paste("alpha=", alphas[i], " & max_k=", max_ks[j], sep = "")
-    }
-  }
+    }  ## end for (j in 1:nmxak)
+  }  ## end for (i 1:nalpha)
   
   runtime <- proc.time() - tic
   rownames(bic) <- paste("alpha=", alphas, sep = "")
