@@ -30,7 +30,7 @@ permCR = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels
   #if the censored indicator is empty, a dummy variable is created
   numCases = dim(dataset)[1];
   if (length(event)==0)  event = vector('numeric',numCases) + 1;
-      if (is.na(csIndex) || length(csIndex) == 0 || csIndex == 0) {
+      if ( length(csIndex) == 0 || sum(csIndex == 0, na.rm = TRUE) > 0 ) {
         cox_results <- survival::coxph(target ~ x, weights = wei )
         stat <- anova(cox_results)[2, 2]
 		    if (stat > 0) {
